@@ -155,15 +155,34 @@ lx_output_mode_valid(xf86OutputPtr output, DisplayModePtr pMode)
     ScrnInfoPtr pScrni = output->scrn;
     GeodeRec *pGeode = GEODEPTR(pScrni);
 
-    /* No scaling > for modes with > 1024 width */
-
-    if (pGeode->Output & OUTPUT_PANEL) {
-	if ((pMode->HDisplay != pGeode->panelMode->HDisplay) &&
-	    pMode->HDisplay > 1024)
-	    return MODE_BAD;
+    /* DCON Panel specific resolution - OLPC's one */
+    if (pGeode->Output & (OUTPUT_PANEL | OUTPUT_DCON)) {
+        if (pGeode->panelMode->HDisplay == 1200 &&
+            pGeode->panelMode->VDisplay == 900)
+            return MODE_OK;
     }
 
-    return MODE_OK;
+    if (pGeode->Output & OUTPUT_PANEL &&
+        gfx_is_panel_mode_supported(pGeode->panelMode->HDisplay,
+                                    pGeode->panelMode->VDisplay,
+                                    pMode->HDisplay,
+                                    pMode->VDisplay,
+                                    pScrni->bitsPerPixel) != -1) {
+
+        return MODE_OK;
+    }
+
+    if (gfx_is_display_mode_supported(pMode->HDisplay,
+                                      pMode->VDisplay,
+                                      pScrni->bitsPerPixel,
+                                      GeodeGetRefreshRate(pMode)) != -1) {
+        return MODE_OK;
+    }
+
+    if (pMode->type & (M_T_DRIVER | M_T_PREFERRED))
+        return MODE_OK;
+
+    return MODE_BAD;
 }
 
 static Bool
